@@ -16,9 +16,6 @@
 
 #include <stddef.h>
 #include <string.h>
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#endif
 #include <sys/stat.h>
 #include <libxml/parser.h>
 #include <libxml/xpath.h>
@@ -409,20 +406,22 @@ lt_xml_get_cldr(lt_xml_t      *xml,
 			xmlDocPtr *d = &pref[idx - 1], doc = NULL;
 
 			do {
-				p = index(pp, ':');
+				p = strchr(pp, ':');
 				if (p)
 					s = lt_strndup(pp, p - pp);
 				else
 					s = strdup(pp);
-				if (!lt_xml_read_cldr_bcp47(xml, s, d, &err))
+				if (!lt_xml_read_cldr_bcp47(xml, s, d, &err)) {
+					free(s);
 					goto bail;
+				}
+				free(s);
 				if (d == &doc) {
 					if (!_lt_xml_merge_keys(xml, pref[idx - 1], doc, &err))
 						goto bail;
 				} else {
 					d = &doc;
 				}
-				free(s);
 				if (p)
 					pp = ++p;
 			} while (p);
